# Table of Contents

- [add-business-capabilities](<./add-business-capabilities.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Add Business Capabilities](<./Add-Business-Capabilities.md>)
  - [Introduction to Business Capabilities](<./Add-Business-Capabilities/Introduction-to-Business-Capabilities.md>)
  - [Required Attributes](<./Add-Business-Capabilities/Required-Attributes.md>)
  - [Define Business Capabilities](<./Add-Business-Capabilities/Define-Business-Capabilities.md>)
  - [Add Business Capabilities](<./Add-Business-Capabilities/Add-Business-Capabilities.md>)
  - [Monitor Progress Using Metrics](<./Add-Business-Capabilities/Monitor-Progress-Using-Metrics.md>)
